@@ -1,6 +1,6 @@
-import mode_selector
-import format_translator
-import Format
+from FPE import mode_selector
+from FPE import format_translator
+from FPE import Format
         
 def encrypt(text,key,tweak,dataFormat,mode):
     if dataFormat == Format.EMAIL:
@@ -37,9 +37,8 @@ def encrypt(text,key,tweak,dataFormat,mode):
         return format_translator.numeral_list_to_text(cipherNumerals, dataFormat)
 
     else:
-        for _ in range(100000):
-            plainNumerals = format_translator.text_to_numeral_list(text, dataFormat)
-            radix = format_translator.get_radix_by_format(dataFormat)
+        plainNumerals = format_translator.text_to_numeral_list(text, dataFormat)
+        radix = format_translator.get_radix_by_format(dataFormat)
 
         
         cipherNumerals = mode_selector.encrypt(plainNumerals,key,tweak,radix,mode)
@@ -79,9 +78,8 @@ def decrypt(text,key,tweak,dataFormat,mode):
         return format_translator.numeral_list_to_text(plainNumerals, dataFormat)
 
     else:
-        for _ in range(100000):
-            radix = format_translator.get_radix_by_format(dataFormat)
-            plainNumerals = format_translator.text_to_numeral_list(text, dataFormat)
+        radix = format_translator.get_radix_by_format(dataFormat)
+        plainNumerals = format_translator.text_to_numeral_list(text, dataFormat)
 
 
         cipherNumerals = mode_selector.decrypt(plainNumerals,key,tweak,radix,mode)
